Area Under the Curve of Binomial GLM predictions vs. observations
Source:R/f_binomial_glm.R
f_binomial_glm.RdFits a Quasibinomial GLM model y ~ x with the binomial response y (values 0 and 1) and the numeric, character, or factor predictor x using stats::glm() and returns the area under the ROC curve of the observations against the predictions (see score_auc()).
Cases are weighted with case_weights() to prevent issues arising from class imbalance.
Supports cross-validation via the arguments arguments cv_training_fraction (numeric between 0 and 1) and cv_iterations (integer between 1 and n) introduced via ellipsis (...). See preference_order() for further details.
See also
Other preference_order_functions:
f_binomial_gam(),
f_binomial_rf(),
f_categorical_rf(),
f_count_gam(),
f_count_glm(),
f_count_rf(),
f_numeric_gam(),
f_numeric_glm(),
f_numeric_rf(),
preference_order()
Examples
data(vi_smol, package = "spatialData")
df <- data.frame(
y = vi_smol[["vi_binomial"]],
x = vi_smol[["swi_max"]]
)
#no cross-validation
f_binomial_glm(df = df)
#> [1] 0.7036958
#cross-validation
f_binomial_glm(
df = df,
cv_training_fraction = 0.5,
cv_iterations = 10
)
#> [1] 0.6464383 0.6912812 0.6897145 0.7125245 0.7051225 0.7614895 0.7104790
#> [8] 0.7048571 0.6632095 0.7040886
#categorical predictor
df <- data.frame(
y = vi_smol[["vi_binomial"]],
x = vi_smol[["koppen_zone"]]
)
f_binomial_glm(df = df)
#> [1] 0.8871705