Fits a univariate random forest model y ~ x with the numeric response y and the numeric, character or factor predictor x using ranger::ranger() and returns the R-squared between the observed responses and returns the R-squared of the observations against the predictions (see score_r2()).
Supports cross-validation via the arguments arguments cv_training_fraction (numeric between 0 and 1) and cv_iterations (integer between 1 and n) introduced via ellipsis (...). See preference_order() for further details.
See also
Other preference_order_functions:
f_binomial_gam(),
f_binomial_glm(),
f_binomial_rf(),
f_categorical_rf(),
f_count_gam(),
f_count_glm(),
f_count_rf(),
f_numeric_gam(),
f_numeric_glm(),
preference_order()
Examples
data(vi_smol, package = "spatialData")
df <- data.frame(
y = vi_smol[["vi_numeric"]],
x = vi_smol[["swi_max"]]
)
#no cross-validation
f_numeric_rf(df = df)
#> [1] 0.6350856
#cross-validation
f_numeric_rf(
df = df,
cv_training_fraction = 0.5,
cv_iterations = 10
)
#> [1] 0.4069261 0.4171651 0.4355200 0.3694806 0.3902885 0.4476269 0.4175229
#> [8] 0.3942283 0.4505915 0.3810338
#categorical predictor
df <- data.frame(
y = vi_smol[["vi_numeric"]],
x = vi_smol[["koppen_zone"]]
)
f_numeric_rf(df = df)
#> [1] 0.7065278