Dataframe with known relationship between responses and predictors useful to illustrate multicollinearity concepts.
Usage
data(toy)Details
Columns:
y: response variable generated froma * 0.75 + b * 0.25 + noise.a: most important predictor ofy, uncorrelated withb.b: second most important predictor ofy, uncorrelated witha.c: generated froma + noise.d: generated from(a + b)/2 + noise.
These are variance inflation factors of the predictors in toy.
variable vif
b 4.062
d 6.804
c 13.263
a 16.161