Fits a univariate random forest model y ~ x with the numeric response y and the numeric, character or factor predictor x using ranger::ranger() and returns the R-squared between the observed responses and returns the R-squared of the observations against the predictions (see score_r2()).
Supports cross-validation via the arguments arguments cv_training_fraction (numeric between 0 and 1) and cv_iterations (integer between 1 and n) introduced via ellipsis (...). See preference_order() for further details.
See also
Other preference_order_functions:
f_binomial_gam(),
f_binomial_glm(),
f_binomial_rf(),
f_categorical_rf(),
f_count_gam(),
f_count_glm(),
f_count_rf(),
f_numeric_gam(),
f_numeric_glm(),
preference_order()
Examples
data(vi_smol, package = "spatialData")
df <- data.frame(
y = vi_smol[["vi_numeric"]],
x = vi_smol[["swi_max"]]
)
#no cross-validation
f_numeric_rf(df = df)
#> [1] 0.7173618
#cross-validation
f_numeric_rf(
df = df,
cv_training_fraction = 0.5,
cv_iterations = 10
)
#> [1] 0.4758171 0.5698220 0.5367727 0.5923606 0.5798969 0.5670728 0.5692485
#> [8] 0.5568086 0.5538495 0.5760723
#categorical predictor
df <- data.frame(
y = vi_smol[["vi_numeric"]],
x = vi_smol[["koppen_zone"]]
)
f_numeric_rf(df = df)
#> [1] 0.8160186