powered by
A fitted generalized additive model describing max_vif as a function of max_cor in experiment_cor_vs_vif.
max_vif
max_cor
data(gam_cor_to_vif)
A gam object.
gam
The model parameters (basis dimension k and weight exponent) were selected via optimization, filtering for models in the top 90\
k
The final model uses squared Jaccard similarity as weights to emphasize cases with high agreement between cor_select() and vif_select().
cor_select()
vif_select()
Model performance:
Adjusted R-squared: 0.834
Deviance explained: 83.4\
Effective degrees of freedom for smooth: ~6
Other experiments: experiment_adaptive_thresholds, experiment_cor_vs_vif, prediction_cor_to_vif
experiment_adaptive_thresholds
experiment_cor_vs_vif
prediction_cor_to_vif
data(gam_cor_to_vif) plot(gam_cor_to_vif, shade = TRUE)
Run the code above in your browser using DataLab